==> qtjambi-remoteobjects-6.2.4-sources.jar: io/qt/remoteobjects/QtROServerIoDevice.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QtROServerIoDevice</p>
 */
public abstract class QtROServerIoDevice extends io.qt.remoteobjects.QtROIoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROServerIoDevice.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QtROServerIoDevice {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.core.QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QtROServerIoDevice(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROServerIoDevice() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROServerIoDevice(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROServerIoDevice instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    protected java.lang.String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QtROServerIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QtROServerIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QtROServerIoDevice instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-6.2.12-sources.jar: io/qt/remoteobjects/QtROServerIoDevice.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QtROServerIoDevice</p>
 */
public abstract class QtROServerIoDevice extends io.qt.remoteobjects.QtROIoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROServerIoDevice.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROServerIoDevice {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROServerIoDevice() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROServerIoDevice(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROServerIoDevice instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    protected java.lang.@NonNull String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QtROServerIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QtROServerIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROServerIoDevice instance, QDeclarativeConstructor constructor);
    
}
